@@ -4,7 +4,8 @@ test_that("index_fqa_databases_internal works", {
 
   skip_if_offline()
 
-  databases <- index_fqa_databases_internal()
+  databases <- suppressMessages(index_fqa_databases_internal())
+
   expect_equal(ncol(databases), 4)
   expect_equal(names(databases), c("database_id", "region", "year", "description"))
   expect_equal(class(databases), c("tbl_df",
