@@ -1,7 +1,7 @@
 test_that("species_acronym works", {
 
   species <- "Anemone canadensis"
-  species2 <- "Andromeda glaucophylla"
+  species2 <- "Andropogon gerardii"
   species3 <- "Abelmoschus esculentus"
 
   expect_error(species_acronym(species),
@@ -13,17 +13,23 @@ test_that("species_acronym works", {
 
   skip_if_offline()
 
-  db <- download_database(1)
-  db_inv <- database_inventory(db)
+  db <- suppressMessages(download_database(149))
+  db_inv <- suppressMessages(database_inventory(db))
 
   expect_error(species_acronym(species, 149, db_inv),
                "database_id and database_inventory cannot both be specified.")
-  expect_message(species_acronym("fake_species", database_inventory = db_inv),
-               "Species not found in specified database.")
   expect_true(is.na(suppressMessages(species_acronym("fake_species",
                                                      database_inventory = db_inv))))
-  expect_equal(species_acronym(species, 149), "ANECAN")
-  expect_equal(species_acronym(species3, 149), "ABEESC")
-  expect_equal(species_acronym(species2, database_inventory = db_inv), "ANDGLA")
+
+  if (!is.na(suppressMessages(species_acronym(species, 149)))) {
+    expect_equal(species_acronym(species, 149), "ANECAN") # for when database download succeeds
+    expect_equal(species_acronym(species3, 149), "ABEESC")
+    expect_equal(species_acronym(species2, database_inventory = db_inv), "ANDGER")
+    expect_message(species_acronym("fake_species", database_inventory = db_inv),
+                   "Species not found in specified database.")
+  } else {
+    # for when database download fails
+    expect_message(species_acronym(species, 149))
+  }
 
 })
