@@ -13,18 +13,22 @@ test_that("species_nativity works", {
 
   skip_if_offline()
 
-  db <- download_database(1)
-  db_inv <- database_inventory(db)
+  db <- suppressMessages(download_database(1))
+  db_inv <- suppressMessages(database_inventory(db))
 
   expect_error(species_nativity(species, 149, db_inv),
                "database_id or database_inventory cannot both be specified.")
-  expect_message(species_nativity("fake_species", database_inventory = db_inv),
-               "Species not found in specified database.")
   expect_true(is.na(suppressMessages(species_nativity("fake_species",
                                                database_inventory = db_inv))))
 
-  expect_equal(species_nativity(species, 149), "native")
-  expect_equal(species_nativity(species3, 149), "non-native")
-  expect_equal(species_nativity(species2, database_inventory = db_inv), "native")
-
+  if (!is.na(suppressMessages(species_nativity(species, 149)))) {
+    expect_equal(species_nativity(species, 149), "native")
+    expect_equal(species_nativity(species3, 149), "non-native")
+    expect_equal(species_nativity(species2, database_inventory = db_inv), "native")
+    expect_message(species_nativity("fake_species", database_inventory = db_inv),
+                   "Species not found in specified database.")
+  } else {
+    # for when database download fails
+    expect_message(species_nativity(species, 149))
+  }
 })
